// -*- C++ -*-
//
//  This file is part of Siena, a wide-area event notification system.
//  See http://www.cs.colorado.edu/serl/siena/
//
//  Authors: See the file AUTHORS for full details.
//
//  Copyright (C) 2002-2004 University of Colorado
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,
//  USA, or send email to serl@cs.colorado.edu.
//
// $Id: conflicting.cc,v 1.2 2008-08-21 15:34:10 carzanig Exp $
//
#include <cassert>
#include <iostream>
#include <vector>
#include "siena/simplify.h"
#include "siena/ssimp_types.h"

using namespace siena;
using namespace std;

int main( int argc, char** argv )
{
  { /* basics */
    Constraint y( string( "y" ), eq_id, (int_t)10 );
    Constraint x( string( "x" ), eq_id, (int_t)10 );
    Constraint d( string( "x" ), eq_id, (siena::double_t)3.141 );
    assert( ! conflicting( x, x ) ); // a constraint never conflicts with itself
    assert( ! conflicting( y, x ) ); // constraints with different names never conflict
    assert( conflicting( x, d ) ); // constraints with same names and
				   // different types always conflict
  }
  { /* c1 with x = a */
    Constraint c1i( string( "x" ), eq_id, (int_t)10 );
    
  }

  { /* old tests */
    Constraint y1( string( "y" ), eq_id, (int_t)10 );
    Constraint c1( string( "x" ), eq_id, (int_t)10 );
    Constraint c2( string( "x" ), lt_id, (int_t)5 );
    Constraint c3( string( "x" ), lt_id, (int_t)20 );
    Constraint c4( string( "x" ), gt_id, (int_t)12 );
    Constraint c5( string( "x" ), gt_id, (int_t)5 );
    Constraint c6( string( "x" ), eq_id, (siena::double_t)3.141 );

    assert( conflicting( c2, c4 ) );
    assert( conflicting( c4, c2 ) );
    assert( !conflicting( c1, c3 ) );
    assert( !conflicting( c3, c1 ) );
    assert( conflicting( c1, c2 ) );
    assert( conflicting( c2, c1 ) );
    assert( conflicting( c1, c4 ) );
    assert( conflicting( c4, c1 ) );
    assert( !conflicting( c3, c4 ) );
    assert( !conflicting( c4, c3 ) );
    assert( conflicting( c1, c6 ) );
    assert( conflicting( c2, c6 ) );
    assert( conflicting( c3, c6 ) );
    assert( conflicting( c4, c6 ) );
    assert( conflicting( c5, c6 ) );
  }
}
